## Product details

Looking for decoration lights that are durable and cost efficient? Want to create a magical effect in your party with warm and sparkling lights?These decorative string lights are what you are looking for.It's a LED photo clips string light. You may put your favourite moments in life or postcards making it a photo wall decor of memories recorded by your camera or polaroids!Without the clips, as a heart-warming twinkle lights decorations as wedding, party, decor, mason jar, Christmas light.You can also use clips to organize and hanging pictures, photos, artwork, prints

Features:
GREAT GIFT : Great gift for your lovers, friends and familiy's birthday party Christmas festival celebration. Warm white color make your life WARM.
Hold GREAT MEMORY-The strand of lights is a very unique way to display pictures in your house. It can make the plain white wall come to life with pictures of all the things that matter to the one you care.
CREATIVE ROMANTIC ATMOSPHERE-- transparent clip which can nip photo or other small Items creating excellent illumination and a warm atmosphere, spreading light and cheer across a wide area. It is indispensable for festival decoration.
DECORATION FOR YOUR HOME- It is awesome to decorate sweet bedroom, parties, weddings, Valentine's Day, Christmas, home, window, bathroom, festival, Holiday, shows, restaurant, hotel, commercial building, shopping center, shopcase. Transparent clip which can nip photo or other small Items creating excellent wonderful and a warm atmosphere.
BATTERY POWERED, Easy to use : String lights 3AA battery powered is very safe and convient for you,not worry about your display being near an outlet or power source.Newest indoor and outdoor battery box with ON / OFF/FLASH feature that is easy to hide and requires 3 AA batteries (NOT Included). It is easy open and close the box.
## Introduction
Ours upgraded version with 50 LED clips and can be adjusted freely. Others have only 20 or 30 LED clips and can't adjust, buy 1 from us nearly Equals 2 From Other.
No need buy a bunch of costly heavy photo frames, No need drill hole or use glue to attach photos on the wall, You can change photos whenever you want, no need troublesome to change out photo frame by frame.
## Product specifications:
LED Color: Warm white
LED Quantity: 100
Transparent Clips Quantity: 50
Copper Wire Length: 33Ft
Battery: 3*AA Batteries (Not including)
Function Mode: steady ON and twinkle
The string light is waterproof, but battery box is not waterproof.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
